pub struct CompressionQueue<const N: usize> { /* private fields */ }Expand description
A statically sized ring-buffer queue used while compressing a column.
The absolute max size of this buffer is 16 elements.
Implementations
Sourceimpl<const N: usize> CompressionQueue<N>
impl<const N: usize> CompressionQueue<N>
Sourcepub fn is_full(&self) -> bool
pub fn is_full(&self) -> bool
Returns true if the queue if the queue would have to overwrite an element to push a new value.
Sourcepub fn is_empty(&self) -> bool
pub fn is_empty(&self) -> bool
Returns true if the queue if there is nothing to pop from the queue.
Sourcepub fn push<T: Bits + Sized>(&mut self, value: T)
pub fn push<T: Bits + Sized>(&mut self, value: T)
Pushes a value into the queue, overwriting the oldest value if the queue is full.
Sourcepub fn pop(&mut self) -> Option<usize>
pub fn pop(&mut self) -> Option<usize>
Pops the oldest value from the queue, returning None if the queue is empty.
Sourcepub fn pop_n<const M: usize>(&mut self) -> [usize; M]
pub fn pop_n<const M: usize>(&mut self) -> [usize; M]
Pop N values from the queue at once, values may not be meaningful if the queue is not of length N.
Sourcepub fn peak_bitcounts<const M: usize>(&mut self) -> [usize; M]
pub fn peak_bitcounts<const M: usize>(&mut self) -> [usize; M]
Peak N values from the queue at once, values may not be meaningful if the queue is not of length N.